import { IEventParam, Metadata } from '@zeedhi/core';
import {
  AlertService, Form, Modal, ModalService,
} from '@zeedhi/common';
import { ZdGrid } from '@zeedhi/vuetify';

export class Opl01600ParametrizacaoDoOPLController {
  private FiltroModal!: Modal;

  public readOnlySubGrupProd: boolean = true;

  public filterValueCDFILIOPELOG: any = null;

  public filterValueCDFILIAL: Array<any> = [];

  public filterValueCDPRODINI: any = null;

  public filterValueCDPRODFIN: any = null;

  public filterValueCDMARCA: Array<any> = [];

  public filterValueCDSUBGRPPROD: Array<any> = [];

  public filterValuePARAMETRIZADO: any = 'Ambos';

  public filterGrid2: any = {};

  public filterGrid3: any = {};

  public async createFiltroModal() {
    this.FiltroModal = await ModalService.createFromJson('pages/opl01600_parametrizacao_do_opl_filtro', true);

    this.FiltroModal.show();
  }

  public destroyFiltroModal() {
    this.FiltroModal?.destroy();
  }

  public async abrirFiltroModal() {
    this.FiltroModal.show();
  }

  public fecharFiltroModal() {
    this.FiltroModal.hide();
  }

  public validaFiltro() {
    const form = Metadata.getInstance<Form>('formFiltro');
    const valid = form.validate();

    if (!valid) {
      AlertService.show({
        top: true,
        right: true,
        timeout: 2000,
        name: 'filtroInvalidoAltert',
        text: 'Preencha todos os campos obrigatórios!',
        color: 'error',
      });
    } else {
      form.submit();

      this.fecharFiltroModal();
    }
  }

  public onChangeSwitchSubGrupProd({ component }: IEventParam<any>) {
    if (this.readOnlySubGrupProd) {
      this.filterValueCDSUBGRPPROD = [];
      component.parent.children.forEach((child: { name: any; value: any; }) => {
        if (child.name === 'CDSUBGRPROD') {
          child.value = [];
        }
      });
    }
  }

  public onChangeFieldsFiltro({ component }: IEventParam<any>) {
    switch (component.name) {
      case 'CDFILIOPELOG': {
        this.filterValueCDFILIOPELOG = component.value;
        break;
      }
      case 'CDFILIAL': {
        this.filterValueCDFILIAL = component.value;
        break;
      }
      case 'CDPRODINI': {
        this.filterValueCDPRODINI = component.value;
        break;
      }
      case 'CDPRODFIN': {
        this.filterValueCDPRODFIN = component.value;
        break;
      }
      case 'CDMARCA': {
        this.filterValueCDMARCA = component.value;
        break;
      }
      case 'CDSUBGRPROD': {
        this.filterValueCDSUBGRPPROD = component.value;
        break;
      }
      case 'PARAMETRIZADO': {
        this.filterValuePARAMETRIZADO = component.value;
        break;
      }
      default: break;
    }
  }

  public onFilterOpen({ component }: IEventParam<any>) {
    component.children.forEach((child: { name: any; value: any; }) => {
      if (child.name === 'CDFILIOPELOG') {
        if (this.filterValueCDFILIOPELOG !== null) {
          child.value = this.filterValueCDFILIOPELOG.CDFILIAL;
        }
      }
      if (child.name === 'CDFILIAL') {
        this.filterValueCDFILIAL.forEach((val) => {
          if (child.value.indexOf(val.CDFILIAL) === -1) {
            child.value.push(val.CDFILIAL);
          }
        });
      }
      if (child.name === 'CDPRODINI') {
        if (this.filterValueCDPRODINI !== null) {
          child.value = this.filterValueCDPRODINI.CDARVPROD;
        }
      }
      if (child.name === 'CDPRODFIN') {
        if (this.filterValueCDPRODFIN !== null) {
          child.value = this.filterValueCDPRODFIN.CDARVPROD;
        }
      }
      if (child.name === 'CDMARCA') {
        this.filterValueCDMARCA.forEach((val) => {
          if (child.value.indexOf(val.CDMARCA) === -1) {
            child.value.push(val.CDMARCA);
          }
        });
      }
      if (child.name === 'CDSUBGRPROD') {
        this.filterValueCDSUBGRPPROD.forEach((val) => {
          if (child.value.indexOf(val.CDSUBGRPROD) === -1) {
            child.value.push(val.CDSUBGRPROD);
          }
        });
      }
    });
  }

  public reload({ component }: any) {
    if (component.parent.name === 'tipoOperacaoOLGrid') {
      component.parent.datasource.get();
    }

    if (component.parent.name === 'parametrizacaoDeProdutoPorUnidadeGrid') {
      component.parent.datasource.filter = this.filterGrid2;
      component.parent.datasource.get();
    }

    if (component.parent.name === 'parametrizacaoGeralDeProdutosGrid') {
      component.parent.datasource.filter = this.filterGrid3;
      component.parent.datasource.get();
    }
  }

  public loadGrid1() {
    const grid = Metadata.getInstance<ZdGrid>('tipoOperacaoOLGrid');
    const arrayCDFILIAL: Array<any> = [];
    const arrayCDSUBGRPPROD: Array<any> = [];
    const arrayCDMARCA: Array<any> = [];
    let valueCDFILIAL: String = '';
    let valueCDSUBGRPPROD: String = '';
    let valueCDMARCA: String = '';

    this.filterValueCDFILIAL.forEach((val) => {
      arrayCDFILIAL.push(val.CDFILIAL);
    });
    valueCDFILIAL = String('_').concat(arrayCDFILIAL.join('_').concat(String('_')));

    this.filterValueCDSUBGRPPROD.forEach((val) => {
      arrayCDSUBGRPPROD.push(val.CDSUBGRPROD);
    });
    valueCDSUBGRPPROD = String('_').concat(arrayCDSUBGRPPROD.join('_').concat(String('_')));

    this.filterValueCDMARCA.forEach((val) => {
      arrayCDMARCA.push(val.CDMARCA);
    });
    valueCDMARCA = String('_').concat(arrayCDMARCA.join('_').concat(String('_')));

    const newFilter1 = {
      P_CDFILIAL: this.filterValueCDFILIAL.length > 0 ? valueCDFILIAL : 'T',
      P_OPERLOG: this.filterValueCDFILIOPELOG.CDFILIAL,
      P_CDOPERADOR: 'OPERADOR_LOGADO',
    };
    const newFilter2 = {
      P_NMPRODINI: this.filterValueCDPRODINI.NMPRODUTO,
      P_NMPRODFIN: this.filterValueCDPRODFIN.NMPRODUTO,
      P_CDFILIAL: this.filterValueCDFILIAL.length > 0 ? valueCDFILIAL : '',
      P_SUBGRUPO: this.filterValueCDSUBGRPPROD.length > 0 ? valueCDSUBGRPPROD : 'N',
      P_CDPRODINI: this.filterValueCDPRODINI.CDARVPROD,
      P_CDFILIOL: String('_').concat(String(this.filterValueCDFILIOPELOG.CDFILIAL).concat(String('_'))),
      P_TCDFILIOL: '',
      P_TCDFILIAL: this.filterValueCDFILIAL.length > 0 ? '' : 'T',
      P_CDPRODFIN: (String(this.filterValueCDPRODFIN.CDARVPROD).concat(String('ZZZZZZZZZZZZZZZZZZZZ'))).substr(0, 20),
      P_CDPRODFINTEXT: this.filterValueCDPRODFIN.CDARVPROD,
    };
    const newFilter3 = {
      P_CDFILIAL: 'FILIAL_LOGADA',
      P_SUBGRUPO: this.filterValueCDSUBGRPPROD.length > 0 ? valueCDSUBGRPPROD : 'N',
      P_CDMARCA: this.filterValueCDMARCA.length > 0 ? valueCDMARCA : 'T',
      P_CDPRODINI: this.filterValueCDPRODINI.CDARVPROD,
      P_CDPRODFIN: (String(this.filterValueCDPRODFIN.CDARVPROD).concat(String('ZZZZZZZZZZZZZZZZZZZZ'))).substr(0, 20),
    };

    grid.datasource.filter = newFilter1;
    grid.datasource.get();

    this.filterGrid2 = newFilter2;
    this.filterGrid3 = newFilter3;
  }

  public loadGrid2({ component }: any) {
    component.datasource.filter = this.filterGrid2;
    component.datasource.get();
  }

  public loadGrid3({ component }: any) {
    component.datasource.filter = this.filterGrid3;
    component.datasource.get();
    this.reload(component.toolbarSlot[4]);
  }
}
